@@ -65,8 +65,12 @@ class KalturaTrackEntryEventType(object):
 # @subpackage Client
 class KalturaUiConfAdminOrderBy(object):
     CREATED_AT_ASC = "+createdAt"
+    ID_ASC = "+id"
+    NAME_ASC = "+name"
     UPDATED_AT_ASC = "+updatedAt"
     CREATED_AT_DESC = "-createdAt"
+    ID_DESC = "-id"
+    NAME_DESC = "-name"
     UPDATED_AT_DESC = "-updatedAt"
 
     def __init__(self, value):
