@@ -105,11 +105,14 @@ class KalturaExternalMediaEntry(KalturaMediaEntry):
     def __init__(self,
             id=NotImplemented,
             name=NotImplemented,
+            multiLingual_name=NotImplemented,
             description=NotImplemented,
+            multiLingual_description=NotImplemented,
             partnerId=NotImplemented,
             userId=NotImplemented,
             creatorId=NotImplemented,
             tags=NotImplemented,
+            multiLingual_tags=NotImplemented,
             adminTags=NotImplemented,
             categories=NotImplemented,
             categoriesIds=NotImplemented,
@@ -177,11 +180,14 @@ class KalturaExternalMediaEntry(KalturaMediaEntry):
         KalturaMediaEntry.__init__(self,
             id,
             name,
+            multiLingual_name,
             description,
+            multiLingual_description,
             partnerId,
             userId,
             creatorId,
             tags,
+            multiLingual_tags,
             adminTags,
             categories,
             categoriesIds,
